@@ -556,6 +556,14 @@ class Hits(Metric):
             )
         )
 
+    def calc_stats_from_rank(
+        self, rank_data: list, config: Optional[MetricConfig] = None
+    ) -> MetricStats:  # TODO(Pengfei): why do we need the 3rd argument?
+        config = cast(HitsConfig, self._get_config(config))
+        return MetricStats(
+            np.array([(1.0 if rank <= config.hits_k else 0.0) for rank in rank_data])
+        )
+
 
 @dataclass
 class MeanReciprocalRankConfig(MetricConfig):
@@ -587,6 +595,13 @@ class MeanReciprocalRank(Metric):
             np.array([self.mrr_val(t, p) for t, p in zip(true_data, pred_data)])
         )
 
+    def calc_stats_from_rank(
+        self, rank_data: list, config: Optional[MetricConfig] = None
+    ) -> MetricStats:
+        return MetricStats(
+            np.array([1.0 / rank for rank in rank_data if rank is not None])
+        )
+
 
 @dataclass
 class MeanRankConfig(MetricConfig):
@@ -614,6 +629,11 @@ class MeanRank(Metric):
             np.array([self.mr_val(t, p) for t, p in zip(true_data, pred_data)])
         )
 
+    def calc_stats_from_rank(
+        self, rank_data: list, config: Optional[MetricConfig] = None
+    ) -> MetricStats:
+        return MetricStats(np.array([rank for rank in rank_data if rank is not None]))
+
 
 class EaaSMetricStats(MetricStats):
     """
@@ -682,6 +702,10 @@ class EaaSMetric(Metric):
         elif self.config.name == 'chrf':
             chrf_class = sacrebleu.CHRF()
             return chrf_class._compute_score_from_stats(list(agg_stats)).score / 100.0
+        elif self.config.name == 'length_ratio':
+            return float(agg_stats[0]) / agg_stats[1]
+        elif self.config.name == 'length':
+            return float(agg_stats[0])
         else:
             return float(agg_stats)
 
