@@ -3,7 +3,6 @@ from __future__ import annotations
 from typing import Any
 
 from datalabs import aggregating
-from tqdm import tqdm
 
 from explainaboard import feature, TaskType
 from explainaboard.info import SysOutputInfo
@@ -12,7 +11,9 @@ from explainaboard.processors.processor import Processor
 from explainaboard.processors.processor_registry import register_processor
 import explainaboard.utils.feature_funcs
 from explainaboard.utils.feature_funcs import get_basic_words, get_lexical_richness
+from explainaboard.utils.logging import progress
 from explainaboard.utils.tokenizer import Tokenizer
+from explainaboard.utils.typing_utils import unwrap
 
 
 @register_processor(TaskType.text_classification)
@@ -26,10 +27,8 @@ class TextClassificationProcessor(Processor):
         return feature.Features(
             {
                 "text": feature.Value("string"),
-                "true_label": feature.ClassLabel(names=["1", "0"], is_bucket=False),
-                "predicted_label": feature.ClassLabel(
-                    names=["1", "0"], is_bucket=False
-                ),
+                "true_label": feature.Value("string"),
+                "predicted_label": feature.Value("string"),
                 "label": feature.Value(
                     dtype="string",
                     description="category",
@@ -38,9 +37,9 @@ class TextClassificationProcessor(Processor):
                         method="bucket_attribute_discrete_value", number=4, setting=1
                     ),
                 ),
-                "sentence_length": feature.Value(
+                "text_length": feature.Value(
                     dtype="float",
-                    description="text length",
+                    description="text length in tokens",
                     is_bucket=True,
                     bucket_info=feature.BucketInfo(
                         method="bucket_attribute_specified_bucket_value",
@@ -48,9 +47,9 @@ class TextClassificationProcessor(Processor):
                         setting=(),
                     ),
                 ),
-                "token_number": feature.Value(
+                "text_chars": feature.Value(
                     dtype="float",
-                    description="the number of chars",
+                    description="text length in characters",
                     is_bucket=True,
                     bucket_info=feature.BucketInfo(
                         method="bucket_attribute_specified_bucket_value",
@@ -92,7 +91,7 @@ class TextClassificationProcessor(Processor):
                 "fre_rank": feature.Value(
                     dtype="float",
                     description=(
-                        "the average rank of each work based on its frequency in "
+                        "the average rank of each word based on its frequency in "
                         "training set"
                     ),
                     is_bucket=True,
@@ -122,10 +121,10 @@ class TextClassificationProcessor(Processor):
         return [AccuracyConfig(name='Accuracy', language=language)]
 
     # --- Feature functions accessible by ExplainaboardBuilder._get_feature_func()
-    def _get_sentence_length(self, sys_info: SysOutputInfo, existing_features: dict):
+    def _get_text_length(self, sys_info: SysOutputInfo, existing_features: dict):
         return len(sys_info.tokenize(existing_features["text"]))
 
-    def _get_token_number(self, sys_info: SysOutputInfo, existing_feature: dict):
+    def _get_text_chars(self, sys_info: SysOutputInfo, existing_feature: dict):
         return len(existing_feature["text"])
 
     def _get_label(self, sys_info: SysOutputInfo, existing_feature: dict):
@@ -142,7 +141,10 @@ class TextClassificationProcessor(Processor):
         self, sys_info: SysOutputInfo, existing_features: dict, statistics: Any
     ):
         return explainaboard.utils.feature_funcs.feat_num_oov(
-            existing_features, statistics, lambda x: x['text'], sys_info.tokenizer
+            existing_features,
+            statistics,
+            lambda x: x['text'],
+            unwrap(sys_info.tokenizer),
         )
 
     # training set dependent features
@@ -151,7 +153,10 @@ class TextClassificationProcessor(Processor):
         self, sys_info: SysOutputInfo, existing_features: dict, statistics: Any
     ):
         return explainaboard.utils.feature_funcs.feat_freq_rank(
-            existing_features, statistics, lambda x: x['text'], sys_info.tokenizer
+            existing_features,
+            statistics,
+            lambda x: x['text'],
+            unwrap(sys_info.tokenizer),
         )
 
     # training set dependent features
@@ -181,7 +186,7 @@ class TextClassificationProcessor(Processor):
         vocab: dict[str, float] = {}
         length_fre: dict[int, float] = {}
         total_samps = 0
-        for sample in tqdm(samples):
+        for sample in progress(samples):
             text = sample["text"]
             tokens = tokenizer(text)
             length = len(tokens)
