@@ -11,6 +11,7 @@ from explainaboard.processors.processor import Processor
 from explainaboard.processors.processor_registry import register_processor
 import explainaboard.utils.feature_funcs
 from explainaboard.utils.tokenizer import Tokenizer
+from explainaboard.utils.typing_utils import unwrap
 
 
 @register_processor(TaskType.text_pair_classification)
@@ -24,10 +25,8 @@ class TextPairClassificationProcessor(Processor):
         return feature.Features(
             {
                 "text": feature.Value("string"),
-                "true_label": feature.ClassLabel(names=["1", "0"], is_bucket=False),
-                "predicted_label": feature.ClassLabel(
-                    names=["1", "0"], is_bucket=False
-                ),
+                "true_label": feature.Value("string"),
+                "predicted_label": feature.Value("string"),
                 "label": feature.Value(
                     dtype="string",
                     is_bucket=True,
@@ -89,7 +88,7 @@ class TextPairClassificationProcessor(Processor):
                 "fre_rank": feature.Value(
                     dtype="float",
                     description=(
-                        "the average rank of each work based on its frequency in "
+                        "the average rank of each word based on its frequency in "
                         "training set"
                     ),
                     is_bucket=True,
@@ -134,7 +133,6 @@ class TextPairClassificationProcessor(Processor):
         )
 
     def _get_label(self, sys_info: SysOutputInfo, existing_feature: dict):
-        # print(f"print_existing_feature: \t {existing_feature}")
         return existing_feature["true_label"]
 
     # training set dependent features
@@ -145,7 +143,7 @@ class TextPairClassificationProcessor(Processor):
             existing_features,
             statistics,
             lambda x: x['text1'] + x['text2'],
-            sys_info.tokenizer,
+            unwrap(sys_info.tokenizer),
         )
 
     # training set dependent features (this could be merged into the above one for
@@ -157,5 +155,5 @@ class TextPairClassificationProcessor(Processor):
             existing_features,
             statistics,
             lambda x: x['text1'] + x['text2'],
-            sys_info.tokenizer,
+            unwrap(sys_info.tokenizer),
         )
