@@ -3,11 +3,13 @@ import unittest
 
 from explainaboard import FileType, get_processor, TaskType
 from explainaboard.loaders.loader_registry import get_custom_dataset_loader
+from explainaboard.metric import HitsConfig, MeanRankConfig, MeanReciprocalRankConfig
 from explainaboard.tests.utils import test_artifacts_path
 
 
 class TestKgLinkTailPrediction(unittest.TestCase):
     artifact_path = os.path.join(test_artifacts_path, "kg_link_tail_prediction")
+    test_data = os.path.join(artifact_path, "data_mini.json")
     dataset_no_custom_feature = os.path.join(artifact_path, "no_custom_feature.json")
     dataset_with_custom_feature = os.path.join(
         artifact_path, "with_custom_feature.json"
@@ -16,7 +18,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
     def test_no_user_defined_features(self):
         loader = get_custom_dataset_loader(
             TaskType.kg_link_tail_prediction,
-            self.dataset_no_custom_feature,
+            self.test_data,
             self.dataset_no_custom_feature,
             dataset_file_type=FileType.json,
             output_file_type=FileType.json,
@@ -27,7 +29,11 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         metadata = {
             "task_name": TaskType.kg_link_tail_prediction.value,
             "dataset_name": "fb15k-237-subset",
-            "metric_names": ["Hits"],
+            "metric_configs": [
+                HitsConfig(name='Hits4', hits_k=4),  # you can modify k here
+                MeanReciprocalRankConfig(name='MRR'),
+                MeanRankConfig(name='MR'),
+            ],
         }
 
         processor = get_processor(TaskType.kg_link_tail_prediction.value)
@@ -40,7 +46,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
     def test_with_user_defined_features(self):
         loader = get_custom_dataset_loader(  # use defaults
             TaskType.kg_link_tail_prediction,
-            self.dataset_with_custom_feature,
+            self.test_data,
             self.dataset_with_custom_feature,
         )
         data = loader.load()
@@ -52,18 +58,20 @@ class TestKgLinkTailPrediction(unittest.TestCase):
                 "id",
                 "true_head",
                 "true_link",
+                'true_head_decipher',
+                'true_tail_decipher',
                 "true_tail",
-                "true_tail_anonymity",
-                "true_label",
+                "predict",
                 "predictions",
                 "rel_type",
+                "true_rank",
             },
         )
 
     def test_sort_buckets_by_value(self):
         loader = get_custom_dataset_loader(
             TaskType.kg_link_tail_prediction,
-            self.dataset_no_custom_feature,
+            self.test_data,
             self.dataset_no_custom_feature,
         )
         data = loader.load()
@@ -72,7 +80,11 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         metadata = {
             "task_name": TaskType.kg_link_tail_prediction.value,
             "dataset_name": "fb15k-237",
-            "metric_names": ["Hits"],
+            "metric_configs": [
+                HitsConfig(name='Hits4', hits_k=4),
+                MeanReciprocalRankConfig(name='MRR'),
+                MeanRankConfig(name='MR'),
+            ],
             "sort_by": "performance_value",
             "sort_by_metric": "first",
         }
@@ -96,7 +108,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
     def test_sort_buckets_by_key(self):
         loader = get_custom_dataset_loader(
             TaskType.kg_link_tail_prediction,
-            self.dataset_no_custom_feature,
+            self.test_data,
             self.dataset_no_custom_feature,
         )
         data = loader.load()
@@ -105,7 +117,11 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         metadata = {
             "task_name": TaskType.kg_link_tail_prediction.value,
             "dataset_name": "fb15k-237",
-            "metric_names": ["Hits"],
+            "metric_configs": [
+                HitsConfig(name='Hits4', hits_k=4),
+                MeanReciprocalRankConfig(name='MRR'),
+                MeanRankConfig(name='MR'),
+            ],
             "sort_by": "key",
         }
 
