@@ -8,6 +8,7 @@ from explainaboard.loaders.loader_registry import (
     get_datalab_loader,
 )
 from explainaboard.tests.utils import test_artifacts_path
+from explainaboard.utils import cache_api
 
 
 class TestNER(unittest.TestCase):
@@ -16,6 +17,11 @@ class TestNER(unittest.TestCase):
     conll_output = os.path.join(artifact_path, "output.tsv")
     conll_output_full = os.path.join(artifact_path, "conll2003-elmo-output.conll")
 
+    json_output_customized = cache_api.cache_online_file(
+        'https://datalab-hub.s3.amazonaws.com/predictions/test-conll03.json',  # noqa
+        'predictions/ner/test-conll03.json',
+    )
+
     def test_generate_system_analysis(self):
         loader = get_custom_dataset_loader(
             TaskType.named_entity_recognition,
@@ -148,3 +154,55 @@ class TestNER(unittest.TestCase):
 
         # 9. Unittest: customized features (TODO(Pengfei):
         #  lacks implementation of dataloader?)
+
+    def test_customized_metadata1(self):
+        loader = get_datalab_loader(
+            TaskType.named_entity_recognition,
+            dataset=DatalabLoaderOption("conll2003", "ner"),
+            output_data=self.json_output_customized,
+            output_source=Source.local_filesystem,
+            output_file_type=FileType.json,
+        )
+        data = loader.load()
+        metadata = loader.user_defined_metadata_configs
+        metadata.update(
+            {
+                "task_name": TaskType.named_entity_recognition.value,
+            }
+        )
+        processor = get_processor(TaskType.named_entity_recognition)
+        sys_info = processor.process(metadata, data)
+        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertGreater(len(sys_info.results.overall), 0)
+
+    def test_customized_metadata2(self):
+
+        # Get metadata
+        file_type = FileType.json
+        dummy_task = TaskType.text_classification
+
+        loader = get_custom_dataset_loader(
+            dummy_task,
+            self.json_output_customized,
+            self.json_output_customized,
+            dataset_file_type=file_type,
+            output_file_type=file_type,
+        )
+        metadata = loader.user_defined_metadata_configs
+
+        # All things (loading & processing) will base on `metadata`
+        loader = get_datalab_loader(
+            metadata['task_name'],
+            dataset=DatalabLoaderOption(
+                metadata['dataset_name'], metadata['sub_dataset_name']
+            ),
+            output_data=self.json_output_customized,
+            output_source=Source.local_filesystem,
+            output_file_type=FileType.json,
+        )
+        data = loader.load()
+        processor = get_processor(TaskType.named_entity_recognition)
+        sys_info = processor.process(metadata, data)
+        processor.print_bucket_info(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertGreater(len(sys_info.results.overall), 0)
