@@ -4,6 +4,7 @@ import abc
 import re
 import string
 import sys
+from typing import Any, Optional
 import unicodedata
 
 from explainaboard.utils.tokenizer import MLQAMixTokenizer, SingleSpaceTokenizer
@@ -11,21 +12,55 @@ from explainaboard.utils.tokenizer import MLQAMixTokenizer, SingleSpaceTokenizer
 
 @abc.abstractmethod
 class Preprocessor:
-    def __init__(self, language: str = "en"):
+    def __init__(
+        self, language: str = "en", resources: Optional[dict[str, Any]] = None
+    ):
         self.language = language
+        self.resources = resources or self.default_resources()
 
     def set_language(self, language: str):
         self.language = language
         return self
 
+    def default_resources(self) -> dict:
+        """Returns default features for this processor."""
+        return {}
+
     @abc.abstractmethod
+    def process(self, s: str, **kwargs) -> str:
+        """
+        Get default processing function
+        :return:
+        """
+        ...
+
     def __call__(self, text: str) -> str:
         """
         preprocess text
         :param text: text to be preprocessed
         :return: preprocessed text
         """
-        ...
+        return self.process(text, **self.resources)
+
+
+class MapPreprocessor(Preprocessor):
+    def default_resources(self) -> dict:
+        """Returns default features for this processor."""
+        return {"dictionary": {}}
+
+    def process(self, s: str, **kwargs) -> str:
+        return kwargs['dictionary'][s] if s in kwargs['dictionary'].keys() else s
+
+
+class KGMapPreprocessor(Preprocessor):
+    def default_resources(self) -> dict:
+        """Returns default features for this processor."""
+        return {"dictionary": {}}
+
+    def process(self, s: str, **kwargs) -> str:
+        return (
+            kwargs['dictionary'][s]["label"] if s in kwargs['dictionary'].keys() else s
+        )
 
 
 class QAPreprocessor(Preprocessor):
@@ -45,12 +80,15 @@ class QAPreprocessor(Preprocessor):
     ss_tokenizer = SingleSpaceTokenizer()
     mlqa_tokenizer = MLQAMixTokenizer()
 
-    def __init__(self, language: str):
-        self.language: str = language
+    def default_resources(self) -> dict:
+        """Returns default features for this processor."""
+        return {"language": self.language}
 
-    def normalize_answer(self, s: str, language: str) -> str:
+    def process(self, s: str, **kwargs) -> str:
         """Lower text and remove punctuation, articles and extra whitespace."""
 
+        language = kwargs['language']
+
         def remove_articles(text, lang):
             if lang == 'en' or lang is None:
                 return re.sub(r'\b(a|an|the)\b', ' ', text)
@@ -93,6 +131,3 @@ class QAPreprocessor(Preprocessor):
         return white_space_fix(
             remove_articles(remove_punc(lower(s)), language), language
         )
-
-    def __call__(self, text: str) -> str:
-        return self.normalize_answer(text, self.language)
